netapp_ontap.resources.data_engine_governance_audit_datacollection_count API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.data_engine_governance_audit_datacollection_count`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineGovernanceAuditDatacollectionCount (*args, **kwargs)`

  Governance audit count information for a data collection.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the governance audit impacted files count for a data collection.

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class DataEngineGovernanceAuditDatacollectionCountSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineGovernanceAuditDatacollectionCount object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `anonymized_count: Size GET`

    Total count of anonymized files for the data collection.

    Example: 1024

  `data_collection: DataEngineGovernanceAuditDatacollectionCountDataCollection GET POST PATCH`

    The data_collection field of the data_engine_governance_audit_datacollection_count.

  `excluded_count: Size GET`

    Total count of excluded files for the data collection.

    Example: 1024

  `total_count: Size GET`

    Total count of files impacted in the data collection.

    Example: 1024

  `workspace: DataEngineGovernanceAuditDatacollectionCountWorkspace GET POST PATCH`

    The workspace field of the data_engine_governance_audit_datacollection_count.